#
# spec file for package jenkins-x-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name jx

Name:           jenkins-x-cli
Version:        3.11.21
Release:        1.1
Summary:        CLI for Jenkins X
License:        Apache-2.0
URL:            https://github.com/jenkins-x/jx
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.22
BuildRequires:  zsh
Provides:       jx = %{version}

%description
Jenkins X provides automated CI+CD for Kubernetes with Preview Environments on
Pull Requests using Cloud Native pipelines from Tekton.

This package contains the CLI called jx.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
# hash will be shortened by COMMIT_HASH:0:8 later
COMMIT_HASH="$(sed -n 's/commit: \(.*\)/\1/p' %_sourcedir/%{name}.obsinfo)"

GO_VERSION="$(go version | sed -e 's/^[^0-9.]*\([0-9.]*\).*/\1/')"

DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")

go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Version=%{version} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Revision=${COMMIT_HASH:0:8} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.Branch=v%{version} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.GitTreeState=clean \
   -X github.com/jenkins-x/jx/pkg/cmd/version.GoVersion=${GO_VERSION} \
   -X github.com/jenkins-x/jx/pkg/cmd/version.BuildDate=${BUILD_DATE}" \
   -o bin/%{executable_name} cmd/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Mon Jan 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.21:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.12
- Update to version 3.11.20:
  * chore(deps): bump golang.org/x/net from 0.30.0 to 0.33.0
- Update to version 3.11.19:
  * chore(deps): bump docker/build-push-action from 4 to 6
- Update to version 3.11.18:
  * chore(deps): bump github/codeql-action from 2 to 3
- Update to version 3.11.17:
  * chore(deps): bump sigstore/cosign-installer from 2.8.1 to 3.7.0
- Update to version 3.11.16:
  * chore(deps): bump docker/login-action from 2 to 3
- Update to version 3.11.15:
  * chore(deps): bump docker/setup-qemu-action from 2 to 3
- Update to version 3.11.14:
  * chore(deps): upgrade to version 0.2.70
- Update to version 3.11.13:
  * chore(deps): upgrade to version 0.7.16
- Update to version 3.11.12:
  * chore(deps): upgrade to version 0.23.12
- Update to version 3.11.11:
  * chore(deps): upgrade to version 0.4.11
- Update to version 3.11.10:
  * chore(deps): upgrade to version 0.10.11
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.9:
  * chore(deps): upgrade jenkins-x-plugins/jx-secret to version
    0.4.10
* Thu Jan 16 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.8:
  * fix: don't require cluster for cli upgrade
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.7:
  * chore(deps): upgrade jenkins-x-plugins/jx-pipeline to version
    0.7.13
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.6:
  * chore(deps): upgrade jenkins-x-plugins/jx-project to version
    0.2.67
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.5:
  * chore(deps): upgrade jenkins-x-plugins/jx-admin to version
    0.3.9
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.4:
  * fix: update contributing go version and pre commit status
* Wed Jan 15 2025 opensuse_buildservice@ojkastl.de
- Update to version 3.11.3:
  * chore(deps): upgrade jenkins-x-plugins/jx-gitops to version
    0.23.9
* Mon Dec 16 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package jenkins-x-cli: CLI for Jenkins-X. Jenkins X provides
  automated CI+CD for Kubernetes with Preview Environments on Pull
  Requests using Cloud Native pipelines from Tekton
